@@ -362,14 +362,14 @@ _SWITCHOVER_USAGE_
     COMMON_MS0030       => "\nパスワードが入力されました\n",
     COMMON_MS0031       => "パスワードファイル \"[0]\" が存在しません\n",
     COMMON_MS0032       => "パスワードファイル \"[0]\" の読み込みに失敗しました\n",
-    COMMON_MS0033       => "SSHパスワードが不正です\n",
+    COMMON_MS0033       => "パスワードファイル \"[0]\" の内容が不正です\n",
     COMMON_MS0034       => "環境設定ファイル (pg-rex_tools.conf) の [0] の設定は、\n".
                            "manual、passfile、nopass のいずれかを指定してください\n",
     COMMON_MS0035       => "パスワードファイル \"[0]\" の権限が 600 ではありません\n",
     COMMON_MS0036       => "指定された PGPATH ([0]) に PostgreSQL コマンドが存在しません\n".
                            "環境設定ファイル (pg-rex_tools.conf) の PGPATH を環境にあわせて設定してください\n",
     COMMON_MS0037       => "PostgreSQL [0] には対応していません\n".
-                           "PostgreSQL 9.4 または 9.5 を使用してください\n",
+                           "PostgreSQL 9.5 または 9.6 を使用してください\n",
     COMMON_MS0038       => "Pacemaker [0] には対応していません\n".
                            "Pacemaker 1.1 を使用してください\n",
     COMMON_MS0039       => "[0] で bindnetaddr ([1]) に対応するネットワークインタフェースが見つかりませんでした\n",
